==> customer-link-project-api-1.0.11-20231113.083954-5-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app95721/dto/res/MemberInfoQueryRes.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app95721.dto.res;

//会员信息查询
public class MemberInfoQueryRes {
    // 会员ID
    private Number id;

    // 会员名称
    private String name;

    // 生日
    private String birthday;

    // 性别（1 男；2 女；）
    private Integer sex;

    // 电话号码
    private String mobile;

    // OpenID
    private String openId;

    // UnionID
    private String unionId;

    // 昵称
    private String nickName;

    // 入会渠道
    private String anniversarySource;

    // 入会时间
    private String anniversaryDate;

    // 等级名称
    private String memberLevelName;

    // 等级体系ID
    private Number memberLevelTemplateId;

    // 会员等级ID
    private Number memberLevelDetailTemplateId;

    // 头像
    private String avatar;

    // 消费积分余额
    private Number pointsBalance;

    // 蛋白值余额
    private Number proteinBalance;

    public Number getId() {
        return id;
    }

    public void setId(Number id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getUnionId() {
        return unionId;
    }

    public void setUnionId(String unionId) {
        this.unionId = unionId;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getAnniversarySource() {
        return anniversarySource;
    }

    public void setAnniversarySource(String anniversarySource) {
        this.anniversarySource = anniversarySource;
    }

    public String getAnniversaryDate() {
        return anniversaryDate;
    }

    public void setAnniversaryDate(String anniversaryDate) {
        this.anniversaryDate = anniversaryDate;
    }

    public String getMemberLevelName() {
        return memberLevelName;
    }

    public void setMemberLevelName(String memberLevelName) {
        this.memberLevelName = memberLevelName;
    }

    public Number getMemberLevelTemplateId() {
        return memberLevelTemplateId;
    }

    public void setMemberLevelTemplateId(Number memberLevelTemplateId) {
        this.memberLevelTemplateId = memberLevelTemplateId;
    }

    public Number getMemberLevelDetailTemplateId() {
        return memberLevelDetailTemplateId;
    }

    public void setMemberLevelDetailTemplateId(Number memberLevelDetailTemplateId) {
        this.memberLevelDetailTemplateId = memberLevelDetailTemplateId;
    }

    public String getAvatar() {
        return avatar;
    }

    public void setAvatar(String avatar) {
        this.avatar = avatar;
    }

    public Number getPointsBalance() {
        return pointsBalance;
    }

    public void setPointsBalance(Number pointsBalance) {
        this.pointsBalance = pointsBalance;
    }

    public Number getProteinBalance() {
        return proteinBalance;
    }

    public void setProteinBalance(Number proteinBalance) {
        this.proteinBalance = proteinBalance;
    }
}

==> customer-link-project-api-1.0.11-20231114.094237-7-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app95721/dto/res/MemberInfoQueryRes.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app95721.dto.res;

//会员信息查询
public class MemberInfoQueryRes {
    private Boolean isRegister;
    // 会员ID
    private Number id;

    // 会员名称
    private String name;

    // 生日
    private String birthday;

    // 性别（1 男；2 女；）
    private Integer sex;

    // 电话号码
    private String mobile;

    // OpenID
    private String openId;

    // UnionID
    private String unionId;

    // 昵称
    private String nickName;

    // 入会渠道
    private String anniversarySource;

    // 入会时间
    private String anniversaryDate;

    // 等级名称
    private String memberLevelName;

    // 等级体系ID
    private Number memberLevelTemplateId;

    // 会员等级ID
    private Number memberLevelDetailTemplateId;

    // 头像
    private String avatar;

    // 消费积分余额
    private Number pointsBalance;

    // 蛋白值余额
    private Number proteinBalance;

    public Number getId() {
        return id;
    }

    public void setId(Number id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getUnionId() {
        return unionId;
    }

    public void setUnionId(String unionId) {
        this.unionId = unionId;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getAnniversarySource() {
        return anniversarySource;
    }

    public void setAnniversarySource(String anniversarySource) {
        this.anniversarySource = anniversarySource;
    }

    public String getAnniversaryDate() {
        return anniversaryDate;
    }

    public void setAnniversaryDate(String anniversaryDate) {
        this.anniversaryDate = anniversaryDate;
    }

    public String getMemberLevelName() {
        return memberLevelName;
    }

    public void setMemberLevelName(String memberLevelName) {
        this.memberLevelName = memberLevelName;
    }

    public Number getMemberLevelTemplateId() {
        return memberLevelTemplateId;
    }

    public void setMemberLevelTemplateId(Number memberLevelTemplateId) {
        this.memberLevelTemplateId = memberLevelTemplateId;
    }

    public Number getMemberLevelDetailTemplateId() {
        return memberLevelDetailTemplateId;
    }

    public void setMemberLevelDetailTemplateId(Number memberLevelDetailTemplateId) {
        this.memberLevelDetailTemplateId = memberLevelDetailTemplateId;
    }

    public String getAvatar() {
        return avatar;
    }

    public void setAvatar(String avatar) {
        this.avatar = avatar;
    }

    public Number getPointsBalance() {
        return pointsBalance;
    }

    public void setPointsBalance(Number pointsBalance) {
        this.pointsBalance = pointsBalance;
    }

    public Number getProteinBalance() {
        return proteinBalance;
    }

    public void setProteinBalance(Number proteinBalance) {
        this.proteinBalance = proteinBalance;
    }

    public Boolean getRegister() {
        return isRegister;
    }

    public void setRegister(Boolean register) {
        isRegister = register;
    }

    public MemberInfoQueryRes(Boolean isRegister) {
        this.isRegister = isRegister;
    }
}
